==> com_clubmanagement_1.1.zip: admin/views/positions/view.html.php <==
<?php

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die();

jimport( 'joomla.application.component.view' );

class ClubmanagementViewPositions extends JView
{
	function display($tpl = null)
	{
		$cid = JRequest::getVar('cid', NULL);
		if (is_array($cid) && count($cid)>1) {
			$cid=$cid[0];
			$items = $this->getModel('Positions')->getPersonalData($cid);
			$people_id = $items[0]->people_id;
		} else if (is_array($cid) && count($cid)==1) {
			$items = $this->getModel('Positions')->getPersonalData($cid[0]);
			$people_id = $items[0]->people_id;
		} else if (JRequest::getVar('task')=='add') {
			$items = array();
			JRequest::setVar('task', 'showall');
			$people = $this->getModel('people')->getData();
			$people = AdministrationHelper::getPeopleWithoutPositions();
			JRequest::setVar('task', 'add');
			$this->assignRef('people', $people);
			$people_id = NULL;
		} else {
			$items = $this->getModel('Positions')->getPersonalData();
			$people_id = $items[0]->people_id;
		}
		$this->assignRef('people_id', $people_id);
		$this->assignRef('items',		$items);
		$lists		= & $this->get( 'Lists');
		$this->assignRef('lists',		$lists);
		$pagination = &$this->get('Pagination');
		$this->assignRef('pagination',		$pagination);

		switch(JRequest::getVar('task')) {
			case "edit":
				JToolBarHelper::save();
				JToolBarHelper::apply();
				JToolBarHelper::cancel();
				/**
				* to avoid empty inserts after successful deleted positions
				*/
				if (empty($people_id)) {
					$people = AdministrationHelper::getPeopleWithoutPositions();
					$this->assignRef('people', $people);
				}
			break;
			case "add":
				JToolBarHelper::save();
				JToolBarHelper::apply();
				JToolBarHelper::cancel();
			break;
			default:
				JToolBarHelper::deleteList();
				JToolBarHelper::editListX();
				JToolBarHelper::addNewX();
			break;
		}

		parent::display($tpl);
	}
	
}

==> com_clubmanagement_1.3.zip: admin/views/positions/view.html.php <==
<?php

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die();

jimport( 'joomla.application.component.view' );

class ClubmanagementViewPositions extends JView
{
	function display($tpl = null)
	{
		$cid = JRequest::getVar('cid', NULL);
		if (is_array($cid) && count($cid)>1) {
			$cid=$cid[0];
			$items = $this->getModel('Positions')->getPersonalData($cid);
			$people_id = $items[0]->people_id;
		} else if (is_array($cid) && count($cid)==1) {
			$items = $this->getModel('Positions')->getPersonalData($cid[0]);
			$people_id = $items[0]->people_id;
		} else if (JRequest::getVar('task')=='add') {
			$items = array();
			JRequest::setVar('task', 'showall');
			$people = $this->getModel('people')->getData();
			$people = AdministrationHelper::getPeopleWithoutPositions();
			JRequest::setVar('task', 'add');
			$this->assignRef('people', $people);
			$people_id = NULL;
		} else {
			$items = $this->getModel('positions')->getPersonalData();
			$people_id = $items[0]->people_id;
		}
//var_dump($items);
		$this->assignRef('people_id', $people_id);
		$this->assignRef('items',		$items);
		$lists		= & $this->get( 'Lists');
		$this->assignRef('lists',		$lists);
		$pagination = &$this->get('Pagination');
		$this->assignRef('pagination',		$pagination);

		switch(JRequest::getVar('task')) {
			case "edit":
				JToolBarHelper::save();
				JToolBarHelper::apply();
				JToolBarHelper::cancel();
				/**
				* to avoid empty inserts after successful deleted positions
				*/
				if (empty($people_id)) {
					$people = AdministrationHelper::getPeopleWithoutPositions();
					$this->assignRef('people', $people);
				}
			break;
			case "add":
				JToolBarHelper::save();
				JToolBarHelper::apply();
				JToolBarHelper::cancel();
			break;
			default:
				JToolBarHelper::deleteList();
				JToolBarHelper::editListX();
				JToolBarHelper::addNewX();
			break;
		}

		parent::display($tpl);
	}
	
}
